Documentation
¶
Overview ¶
Package virtual contains an implementation of an IPX network that forwards packets between nodes, similar to a network switch.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // UnknownNodeError is returned by Network.Write() if the destination // MAC address is not associated with any known node. UnknownNodeError = errors.New("unknown destination address") )
Functions ¶
This section is empty.
Types ¶
type Network ¶
type Network struct {
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.